@@ -1,20 +1,6 @@
 # 2ping - A bi-directional ping utility
-# Copyright (C) 2010-2020 Ryan Finnie
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# Copyright (C) 2010-2021 Ryan Finnie
+# SPDX-License-Identifier: GPL-2.0+
 
 import errno
 import logging
@@ -738,8 +724,8 @@ class TwoPing:
                 )
             )
 
-    def close_socks(self, sock_classes=None):
-        if sock_classes is None:
+    def close_socks(self, sock_classes=()):
+        if sock_classes == ():
             sock_classes = self.sock_classes_open
         for sock_class in sock_classes:
             self.logger.debug("Closing socket: {}".format(sock_class))
